
Changelog
=========

0.4.0
-----
* Recoil Impulse solver added to extras module.
* Firearm Code made optional for all Recoil solvers.

0.3.0 (2018-02-12)
------------------
* Recoil Velocity solver added to extras module.

0.2.0 (2018-02-10)
------------------
* Free Recoil Energy solver added to extras module.

0.1.1 (2018-02-07)
------------------
* Implementation no longer supports PyPy (for now).

0.1.0 (2018-02-06)
------------------
* First release on PyPI.
